Index: include/v8.h |
diff --git a/include/v8.h b/include/v8.h |
index f64b3867367ab1f65729b04c4b6666c1a385fc1c..ec92c2b84617df39a458d5a332d8291bf88e602c 100644 |
--- a/include/v8.h |
+++ b/include/v8.h |
@@ -855,12 +855,15 @@ class V8EXPORT String : public Primitive { |
* \param start The starting position within the string at which |
* copying begins. |
* \param length The number of bytes to copy from the string. |
* \return The number of characters copied to the buffer |
* excluding the NULL terminator. |
*/ |
int Write(uint16_t* buffer, int start = 0, int length = -1) const; // UTF-16 |
int WriteAscii(char* buffer, int start = 0, int length = -1) const; // ASCII |
- int WriteUtf8(char* buffer, int length = -1) const; // UTF-8 |
+ int WriteUtf8(char* buffer, |
+ int length = -1, |
+ int* nchars_ref = NULL) const; // UTF-8 |
/** |
* A zero length string. |
@@ -855,12 +855,15 @@ class V8EXPORT String : public Primitive { |
* copying begins. |
* \param length The number of bytes to copy from the string. |
- * \return The number of characters copied to the buffer |
+ * \param nchars The number of characters written. |
+ * \return The number of bytes copied to the buffer |
* excluding the NULL terminator. |
*/ |